@@ -6,15 +6,15 @@ define([
     const { changeOldToNewState
             , findStateValue
             , mapTypeToName } = api;
-    const { BLOCK_CODE_BTN_TYPE
-            , BLOCK_CODE_TYPE
+    const { BLOCK_CODELINE_BTN_TYPE
+            , BLOCK_CODELINE_TYPE
             , BLOCK_DIRECTION
             , BLOCK_TYPE
             , MAKE_CHILD_BLOCK
 
-            , BLOCK_HEIGHT_PX
-            , INDENT_DEPTH_PX
-            , MAX_ITERATION
+            , NUM_BLOCK_HEIGHT_PX
+            , NUM_INDENT_DEPTH_PX
+            , NUM_MAX_ITERATION
             , NUM_ZERO
             
             , STR_TOP
@@ -129,14 +129,14 @@ define([
         /** root dom 생성 */
         var rootDomElement = document.createElement(STR_DIV);
         rootDomElement.classList.add('vp-block');
-        var type = this.getType();
+        var type = this.getBlockCodeLineType();
 
-        if (type === BLOCK_CODE_TYPE.CLASS || type === BLOCK_CODE_TYPE.DEF || type === BLOCK_CODE_TYPE.RETURN) {
+        if (type === BLOCK_CODELINE_TYPE.CLASS || type === BLOCK_CODELINE_TYPE.DEF || type === BLOCK_CODELINE_TYPE.RETURN) {
             $(rootDomElement).css(STR_BACKGROUND_COLOR, `${COLOR_BLUE}`);
-        } else if (type === BLOCK_CODE_TYPE.IF || type === BLOCK_CODE_TYPE.ELSE || type === BLOCK_CODE_TYPE.ELIF
-            || type === BLOCK_CODE_TYPE.FOR || type === BLOCK_CODE_TYPE.WHILE || type === BLOCK_CODE_TYPE.TRY
-            || type === BLOCK_CODE_TYPE.FOR_ELSE || type === BLOCK_CODE_TYPE.EXCEPT || type === BLOCK_CODE_TYPE.FINALLY
-            || type === BLOCK_CODE_TYPE.BREAK || type === BLOCK_CODE_TYPE.CONTINUE || type === BLOCK_CODE_TYPE.PASS) {
+        } else if (type === BLOCK_CODELINE_TYPE.IF || type === BLOCK_CODELINE_TYPE.ELSE || type === BLOCK_CODELINE_TYPE.ELIF
+            || type === BLOCK_CODELINE_TYPE.FOR || type === BLOCK_CODELINE_TYPE.WHILE || type === BLOCK_CODELINE_TYPE.TRY
+            || type === BLOCK_CODELINE_TYPE.FOR_ELSE || type === BLOCK_CODELINE_TYPE.EXCEPT || type === BLOCK_CODELINE_TYPE.FINALLY
+            || type === BLOCK_CODELINE_TYPE.BREAK || type === BLOCK_CODELINE_TYPE.CONTINUE || type === BLOCK_CODELINE_TYPE.PASS) {
             $(rootDomElement).css(STR_BACKGROUND_COLOR, `${COLOR_RED}`);
         }
 
@@ -149,7 +149,7 @@ define([
         var rootInnerDomElement = $(`<div class='vp-block-inner'></div>`);
         var nameDom = $(`<div class='vp-block-header'>
                             <strong class="vp-nodeeditor-style-flex-column-center 
-                                    ${this.getType() !== BLOCK_CODE_TYPE.HOLDER ? 'vp-block-name' : ''}" 
+                                    ${this.getBlockCodeLineType() !== BLOCK_CODELINE_TYPE.HOLDER ? 'vp-block-name' : ''}" 
                                 style="margin-right:10px; font-size:12px; color: #252525;">
                                 ${this.getName()}
                             </strong>    
@@ -161,7 +161,7 @@ define([
         if (blockType === BLOCK_TYPE.BLOCK) {
             var blockWidth = this.realBlock.getWidth();
             $(rootDomElement).css(STR_WIDTH, blockWidth);
-            if (type === BLOCK_CODE_TYPE.CLASS || type === BLOCK_CODE_TYPE.DEF) {
+            if (type === BLOCK_CODELINE_TYPE.CLASS || type === BLOCK_CODELINE_TYPE.DEF) {
             
                 var blockLeftHolder = $('<div class="vp-block-left-holder"></div>');
                 var blockLeftHolderHeight = this.realBlock.getTempBlockLeftHolderHeight();
@@ -169,11 +169,12 @@ define([
                 $(blockLeftHolder).css(STR_BACKGROUND_COLOR,`${COLOR_BLUE}`);
                 $(blockLeftHolder).css(STR_OPACITY, '0.4');
           
+                this.realBlock.setBlockLeftHolderDom(blockLeftHolder);
                 $(rootDomElement).append(blockLeftHolder);
         
-            } else if (type === BLOCK_CODE_TYPE.IF || type === BLOCK_CODE_TYPE.ELSE || type === BLOCK_CODE_TYPE.ELIF
-                    || type === BLOCK_CODE_TYPE.FOR || type === BLOCK_CODE_TYPE.WHILE || type === BLOCK_CODE_TYPE.TRY
-                    || type === BLOCK_CODE_TYPE.FOR_ELSE || type === BLOCK_CODE_TYPE.EXCEPT || type === BLOCK_CODE_TYPE.FINALLY
+            } else if (type === BLOCK_CODELINE_TYPE.IF || type === BLOCK_CODELINE_TYPE.ELSE || type === BLOCK_CODELINE_TYPE.ELIF
+                    || type === BLOCK_CODELINE_TYPE.FOR || type === BLOCK_CODELINE_TYPE.WHILE || type === BLOCK_CODELINE_TYPE.TRY
+                    || type === BLOCK_CODELINE_TYPE.FOR_ELSE || type === BLOCK_CODELINE_TYPE.EXCEPT || type === BLOCK_CODELINE_TYPE.FINALLY
                     ) {
                         
                 var blockLeftHolder = $('<div class="vp-block-left-holder"></div>');
@@ -182,6 +183,7 @@ define([
                 $(blockLeftHolder).css(STR_BACKGROUND_COLOR,`${COLOR_RED}`);
                 $(blockLeftHolder).css(STR_OPACITY, '0.4');
             
+                this.realBlock.setBlockLeftHolderDom(blockLeftHolder);
                 $(rootDomElement).append(blockLeftHolder);
     
             } else {
@@ -235,7 +237,7 @@ define([
             name
         });
     }
-    ShadowBlock.prototype.getType = function() {
+    ShadowBlock.prototype.getBlockCodeLineType = function() {
         return this.state.type;
     }
     ShadowBlock.prototype.setType = function(type) {
