@@ -91,9 +91,9 @@ define([
 
             /**
              * 추가 + 이진용 주임
-             * 2020 10 22 한글('코드가 실행되었습니다') -> 영어로 변경('your code has been executed)
+             * 2020 10 22 한글('코드가 실행되었습니다') -> 영어로 변경('Your code has been executed)
              */
-            vpCommon.renderSuccessMessage("your code has been executed");
+            vpCommon.renderSuccessMessage("Your code has been executed");
         }
     }
 
