@@ -12,7 +12,7 @@ define([
     const funcOptProp = {
         stepCount : 1
         , funcName : "Figure 구성"
-        , funcID : "mp001"  // TODO: ID 규칙 생성 필요
+        , funcID : "mp_figure"  // TODO: ID 규칙 생성 필요
     }
 
     /**
@@ -59,8 +59,8 @@ define([
     var MatplotPackage = function(uuid) {
         this.uuid = uuid;           // Load html 영역의 uuid.
         this.package = {
-            name: '차트 구성',
-            code: '%o0, ax = plt.subplots(%subplotsRows, %subplotsCols%v)',
+            name: 'plt.subplots()',
+            code: '${o0}, ax = plt.subplots(${subplotsRows}, ${subplotsCols}${v})',
             input: [
                 {
                     name: 'subplotsRows',
