@@ -11,8 +11,8 @@ define([
     // 옵션 속성
     const funcOptProp = {
         stepCount : 1
-        , funcName : "플롯 구성"
-        , funcID : "mp002"  // TODO: ID 규칙 생성 필요
+        , funcName : "Create chart"
+        , funcID : "mp_plot"  // TODO: ID 규칙 생성 필요
     }
 
     /**
@@ -58,9 +58,9 @@ define([
      */
     var MatplotPackage = function(uuid) {
         this.uuid = uuid;           // Load html 영역의 uuid.
-        this.package = {
+        this.plotPackage = {
             'plot': {
-                code: '%i0.%kind(%x, %y%v%etc)',
+                code: '${i0}.${kind}(${x}, ${y}${v}${etc})',
                 input: [
                     {
                         name: 'i0',
@@ -107,7 +107,7 @@ define([
                 ]
             },
             'bar': {
-                code: '%i0.%kind(%x, %y%v%etc)',
+                code: '${i0}.${kind}(${x}, ${y}${v}${etc})',
                 input: [
                     {
                         name: 'i0',
@@ -150,7 +150,7 @@ define([
                 ]
             },
             'barh': {
-                code: '%i0.%kind(%x, %y%v%etc)',
+                code: '${i0}.${kind}(${x}, ${y}${v}${etc})',
                 input: [
                     {
                         name: 'i0',
@@ -193,7 +193,7 @@ define([
                 ]
             },
             'hist': {
-                code: '%i0.%kind(%x%v%etc)',
+                code: '${i0}.${kind}(${x}${v}${etc})',
                 input: [
                     {
                         name: 'i0',
@@ -237,7 +237,7 @@ define([
                 ]
             },
             'boxplot': {
-                code: '%i0.%kind(%x, %y%v%etc)',
+                code: '${i0}.${kind}(${x}, ${y}${v}${etc})',
                 input: [
                     {
                         name: 'i0',
@@ -265,7 +265,7 @@ define([
                 ]
             },
             'stackplot': {
-                code: '%i0.%kind(%x, %y%v%etc)',
+                code: '${i0}.${kind}(${x}, ${y}${v}${etc})',
                 input: [
                     {
                         name: 'i0',
@@ -304,8 +304,8 @@ define([
                 ]
             },
             'pie': {
-                code: '%i0.%kind(%x%v%etc)',
-                tailCode: `%i0.axis('equal')`,
+                code: '${i0}.${kind}(${x}${v}${etc})',
+                tailCode: `${i0}.axis('equal')`,
                 input: [
                     {
                         name: 'i0',
@@ -328,7 +328,7 @@ define([
                 ]
             },
             'hexbin': {
-                code: '%i0.%kind(%x, %y%v%etc)',
+                code: '${i0}.${kind}(${x}, ${y}${v}${etc})',
                 input: [
                     {
                         name: 'i0',
@@ -365,8 +365,8 @@ define([
                 ]
             },
             'contour': {
-                code: '%i0.%kind(%x, %y, %z%v%etc)',
-                tailCode: '%i0.colorbar()', // 색상 막대 범례 표시
+                code: '${i0}.${kind}(${x}, ${y}, ${z}${v}${etc})',
+                tailCode: '${i0}.colorbar()', // 색상 막대 범례 표시
                 input: [
                     {
                         name: 'i0',
@@ -407,7 +407,7 @@ define([
                 ]
             },
             'imshow': {
-                code: '%i0.%kind(%z%v%etc)',
+                code: '${i0}.${kind}(${z}${v}${etc})',
                 input: [
                     {
                         name: 'i0',
@@ -442,10 +442,12 @@ define([
                 ]
             }
         };
+        this.package = this.plotPackage['plot'];
+        
         this.optionalPackage = {
             'title': {
-                code: '%i0.set_title(%title)',
-                code2: 'plt.title(%title)',
+                code: '${i0}.set_title(${title})',
+                code2: 'plt.title(${title})',
                 input: [
                     {
                         name: 'i0',
@@ -460,8 +462,8 @@ define([
                 ]
             },
             'xlabel': {
-                code: '%i0.set_xlabel(%xlabel)',
-                code2: 'plt.xlabel(%xlabel)',
+                code: '${i0}.set_xlabel(${xlabel})',
+                code2: 'plt.xlabel(${xlabel})',
                 input: [
                     {
                         name: 'i0',
@@ -476,8 +478,8 @@ define([
                 ]
             },
             'ylabel': {
-                code: '%i0.set_ylabel(%ylabel)',
-                code2: 'plt.ylabel(%ylabel)',
+                code: '${i0}.set_ylabel(${ylabel})',
+                code2: 'plt.ylabel(${ylabel})',
                 input: [
                     {
                         name: 'i0',
@@ -492,8 +494,8 @@ define([
                 ]
             },
             'xlim': {
-                code: '%i0.set_xlim(%xlim)',
-                code2: 'plt.xlim(%xlim)',
+                code: '${i0}.set_xlim(${xlim})',
+                code2: 'plt.xlim(${xlim})',
                 input: [
                     {
                         name: 'i0',
@@ -508,8 +510,8 @@ define([
                 ]
             },
             'ylim': {
-                code: '%i0.set_ylim(%ylim)',
-                code2: 'plt.ylim(%ylim)',
+                code: '${i0}.set_ylim(${ylim})',
+                code2: 'plt.ylim(${ylim})',
                 input: [
                     {
                         name: 'i0',
@@ -524,8 +526,8 @@ define([
                 ]
             },
             'legend': {
-                code: '%i0.legend(%v)',
-                code2: 'plt.legend(%v)',
+                code: '${i0}.legend(${v})',
+                code2: 'plt.legend(${v})',
                 input: [
                     {
                         name: 'i0',
@@ -618,7 +620,7 @@ define([
      * 선택한 패키지명 입력
      */
     MatplotPackage.prototype.showFunctionTitle = function() {
-        $(this.wrapSelector('.vp_functionName')).text('Plot 구성');
+        $(this.wrapSelector('.vp_functionName')).text(funcOptProp.funcName);
     }
 
     /**
@@ -772,8 +774,8 @@ define([
         // 차트유형 선택지에 맞게 옵션 표시
         $(selector).change(function() {
             var kind = $(this).val();
-            var package = that.package[kind];
-            if (package == undefined) package = that.package['plot'];
+            var package = that.plotPackage[kind];
+            if (package == undefined) package = that.plotPackage['plot'];
 
             // 모두 숨기기 (단, 대상 변수 입력란과 차트 유형 선택지 제외)
             $(that.wrapSelector('#vp_plotSetting table tr:gt(2)')).hide();
@@ -788,7 +790,7 @@ define([
         });
 
         // 플롯 차트 옵션으로 초기화
-        var plotPackage = this.package['plot'];
+        var plotPackage = this.plotPackage['plot'];
         // 모두 숨기기 (단, 대상 변수 입력란과 차트 유형 선택지 제외)
         $(this.wrapSelector('#vp_plotSetting table tr:gt(2)')).hide();
 
@@ -869,7 +871,7 @@ define([
     MatplotPackage.prototype.simpleCodeGenerator = function(code, input, variable=[]) {
         input.forEach(obj => {
             var val = pdGen.vp_getTagValue(this.uuid, obj);
-            code = code.split('%' + obj.name).join(val);
+            code = code.split('${' + obj.name + '}').join(val);
         });
         var opt_params = '';
         variable.forEach(obj => {
@@ -884,9 +886,9 @@ define([
                 opt_params += ', ' + obj.key + '=' + val;
             }
         });
-        code = code.split('%v').join(opt_params);
+        code = code.split('${v}').join(opt_params);
 
-        // () 함수 파라미터 공간에 input 없을 경우 (, %v) 와 같은 형태로 출력되는 것 방지
+        // () 함수 파라미터 공간에 input 없을 경우 (, ${v}) 와 같은 형태로 출력되는 것 방지
         code = code.split('(, ').join('(');
 
         return code;
@@ -922,10 +924,10 @@ define([
                 
                 // 패키지 복사
                 var kind = $(this.wrapSelector('#kind')).val();
-                var package = this.package[kind];
+                var package = this.plotPackage[kind];
                 // 원하는 패키지가 없으면 기본 플롯 옵션 불러오기
                 if (package == undefined) {
-                    package = this.package['plot'];
+                    package = this.plotPackage['plot'];
                 }
                 package = JSON.parse(JSON.stringify(package));
 
@@ -962,7 +964,7 @@ define([
 
                 // 꼬리 코드 입력
                 if (package.tailCode != undefined) {
-                    sbCode.append('\n' + package.tailCode.split('%i0').join(i0Input));
+                    sbCode.append('\n' + package.tailCode.split('${i0}').join(i0Input));
                 }
             }
 
