@@ -1,13 +1,8 @@
 define ([
-    'require'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    // numpy 패키지를 위한 라이브러리import 
- 
-    , 'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function(requirejs, vpCommon, 
-            NumpyPageRender ) {
+    'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
+], function( NumpyPageRender ) {
 
-    "use strict";
+    'use strict';
     /**
      * @class NpIdentityPageRender
      * @constructor
@@ -35,18 +30,18 @@ define ([
         var numpyStateGenerator = numpyPageRenderThis.getStateGenerator();
      
         // state의 paramData 객체의 키값을 string 배열로 리턴
-        var stateParamNameStrArray = Object.keys(numpyStateGenerator.getState("paramData"));
+        var stateParamNameStrArray = Object.keys(numpyStateGenerator.getState('paramData'));
         var bindFuncData = {
             numpyPageRenderThis: numpyPageRenderThis
             , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
             , stateParamNameStrOrStrArray: [stateParamNameStrArray[0]] 
-            , paramNameStrArray: ["n행 x n열"]
-            , placeHolderArray: ["숫자 n 입력"]
+            , paramNameStrArray: ['n행 x n열']
+            , placeHolderArray: ['숫자 n 입력']
         }
         this.renderPrefixCode();
 
         this.renderRequiredInputOutputContainer();
-        this.renderInputIndexValueBlock("Input Parameter Int Number", bindFuncData);
+        this.renderInputIndexValueBlock('Input Parameter Int Number', bindFuncData);
 
         /** 옵션 창 */
         this.renderAdditionalOptionContainer();
