@@ -1,12 +1,7 @@
 define ([
-    'require'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    // numpy 패키지를 위한 라이브러리import 
-    , 'nbextensions/visualpython/src/common/constant_numpy'
-    , 'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function( requirejs, vpCommon, 
-             vpNumpyConst, NumpyPageRender ) {
-    "use strict";
+    'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
+], function( NumpyPageRender ) {
+    'use strict';
 
     /**
      * @class NpSplitPageRender
@@ -40,45 +35,45 @@ define ([
         const { PARAM_ONE_ARRAY_EDITOR_TYPE, PARAM_TWO_ARRAY_EDITOR_TYPE,
                 PARAM_THREE_ARRAY_EDITOR_TYPE, PARAM_INPUT_EDITOR_TYPE, PARAM_ONE_ARRAY_INDEX_N_EDITOR_TYPE } = this.numpyEnumRenderEditorFuncType;
         // state의 paramData 객체의 키값을 string 배열로 리턴
-        var stateParamNameStrArray = Object.keys(this.numpyStateGenerator.getState("paramData"));
-        var tabTitle = "Input Spliting Array";
+        var stateParamNameStrArray = Object.keys(this.numpyStateGenerator.getState('paramData'));
+        var tabTitle = 'Input Spliting Array';
         var tabBlockArray = [
             {
                 tabNumber: 1
-                , btnText: "X개 배열로 분할"
+                , btnText: 'X개 배열로 분할'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [stateParamNameStrArray[0]]
-                    , paramNameStrArray: ["X"]
-                    , placeHolderArray: ["숫자 입력"]
+                    , paramNameStrArray: ['X']
+                    , placeHolderArray: ['숫자 입력']
                 }
             },
             {
                 tabNumber: 2
-                , btnText: "[0:X] [X:Y] [Y:] 3개 배열로 분할"
+                , btnText: '[0:X] [X:Y] [Y:] 3개 배열로 분할'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[1], stateParamNameStrArray[2]]
-                    , paramNameStrArray: ["X",  "Y"]
-                    , placeHolderArray: ["숫자 입력", "숫자 입력"]
+                    , paramNameStrArray: ['X',  'Y']
+                    , placeHolderArray: ['숫자 입력', '숫자 입력']
                 }
             },
             {
                 tabNumber: 3
-                , btnText: "[0:X] [X:Y] [Y:Z] [Z:] 4개 배열로 분할"
+                , btnText: '[0:X] [X:Y] [Y:Z] [Z:] 4개 배열로 분할'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray:  [ stateParamNameStrArray[3], stateParamNameStrArray[4], stateParamNameStrArray[5]]
-                    , paramNameStrArray: [ "X",  "Y", "Z" ]
-                    , placeHolderArray: ["숫자 입력", "숫자 입력", "숫자 입력"]
+                    , paramNameStrArray: [ 'X',  'Y', 'Z' ]
+                    , placeHolderArray: ['숫자 입력', '숫자 입력', '숫자 입력']
                 }
             },
             {
                 tabNumber: 4
-                , btnText: "N개 배열로 분할"
+                , btnText: 'N개 배열로 분할'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_ONE_ARRAY_INDEX_N_EDITOR_TYPE
@@ -95,7 +90,7 @@ define ([
 
         this.renderRequiredInputOutputContainer();
         this.renderParamTabBlock(tabDataObj);
-        this.renderParamVarBlock("Input Array Variable");
+        this.renderParamVarBlock('Input Array Variable');
 
         /** 옵션 창 */
         this.renderAdditionalOptionContainer();
