@@ -3,10 +3,10 @@ define ([
 ], function( vpCommon ) {
 
     var _renderRequiredInputOutputContainer = function(numpyPageRendererThis) {
-        var uuid = vpCommon.getUUID();
+        // var uuid = vpCommon.getUUID();
         var numpyPageRendererThis = numpyPageRendererThis;
-        var importPackageThis = numpyPageRendererThis.getImportPackageThis();
-        var numpyStateGenerator = numpyPageRendererThis.getStateGenerator();
+        // var importPackageThis = numpyPageRendererThis.getImportPackageThis();
+        // var numpyStateGenerator = numpyPageRendererThis.getStateGenerator();
      
         var rootTagSelector = numpyPageRendererThis.getRootTagSelector();
         var optionPage = $(numpyPageRendererThis.importPackageThis.wrapSelector(rootTagSelector));
