@@ -1,7 +1,7 @@
 define ([
       './_renderParamArrayEditorTitle'
     , './_resetArrayEditor'
-    , './_renderEditorModalOpenBtn'
+    // , './_renderEditorModalOpenBtn'
     , './_renderParamTabBlock'
     , './_renderParamOneArrayEditor'
     , './_renderParamTwoArrayEditor'
@@ -25,7 +25,7 @@ define ([
 ], function(
     _renderParamArrayEditorTitle
     , _resetArrayEditor
-    , _renderEditorModalOpenBtn
+    // , _renderEditorModalOpenBtn
     , _renderParamTabBlock
     , _renderParamOneArrayEditor
     , _renderParamTwoArrayEditor
@@ -50,7 +50,7 @@ define ([
     return {
         _renderParamArrayEditorTitle
         , _resetArrayEditor
-        , _renderEditorModalOpenBtn
+        // , _renderEditorModalOpenBtn
         , _renderParamTabBlock
         , _renderParamOneArrayEditor
         , _renderParamTwoArrayEditor
