@@ -7,7 +7,7 @@ define([
     , 'nbextensions/visualpython/src/common/vpFuncJS'
 
     // numpy 패키지를 위한 라이브러리import 
-    , 'nbextensions/visualpython/src/common/constant_numpy'
+    , 'nbextensions/visualpython/src/numpy/constant_numpy'
     , 'nbextensions/visualpython/src/numpy/api/numpyStateApi'
     , 'nbextensions/visualpython/src/numpy/api/numpyRouteMapApi'
  
