@@ -13,7 +13,8 @@ define([
     const funcOptProp = {
         stepCount : 1
         , funcName : "To Pickle"
-        , funcID : "pd078"  // TODO: ID 규칙 생성 필요
+        , funcID : "pdIo_toPickle"
+        , libID : "pd078"
     }
 
     /**
@@ -60,7 +61,7 @@ define([
     var PandasPackage = function(uuid) {
         this.uuid = uuid;   // Load html 영역의 uuid.
         // pandas 함수
-        this.package = libPandas._PANDAS_FUNCTION[funcOptProp.funcID];
+        this.package = libPandas._PANDAS_FUNCTION[funcOptProp.libID];
         
         // file navigation : state 데이터 목록
         this.state = {
