@@ -231,7 +231,7 @@
         var visibleSidebar = cfg.sideBar && sidebar.is(':visible');
         var sidebarWidth = visibleSidebar ? sidebar.outerWidth() : 0;
         var availableSpace = nbWrapWidth - 2 * margin - sidebarWidth;
-        // console.log('sidebarWidth : ', sidebarWidth);
+        
         var innerCtyle = {
             marginRight: '',
             width: ''
@@ -256,11 +256,10 @@
      */
     var saveVpPosition = function () {
         var vpWrapper = $(vpCommon.getVPContainer());
-        var newValues = vpWrapper.hasClass('sidebar-wrapper') ? ['width'] : ['right', 'top', 'height', 'width'];
+        var newValues = ['width'];
         $.extend(vpPosition, vpWrapper.css(newValues));
         setVpMetaData(vpConst.VP_POSITION_META_NAME, vpPosition);
-        if (vpWrapper.hasClass('sidebar-wrapper'))
-            $(vpCommon.getVPContainer()).css('left', '');
+        $(vpCommon.getVPContainer()).css('left', '');
         events.trigger('resize-container.vp-wrapper');
     };
 
@@ -304,18 +303,24 @@
      * @param {defaultConfig} cfg 설정값
      */
     var toggleSidebar = function (cfg) {
-        var makeSidebar = cfg.sideBar;
+        // var makeSidebar = cfg.sideBar;
+        // var viewRect = (liveNotebook ? document.getElementById('site') : document.body).getBoundingClientRect();
+        // var wrap = $(vpCommon.getVPContainer())
+        //     .toggleClass('sidebar-wrapper', makeSidebar)
+        //     .toggleClass('float-wrapper', !makeSidebar)
+        //     .resizable('option', 'handles', makeSidebar ? 'w' : 'all');
+        // wrap.children('.ui-resizable-w').toggleClass('ui-icon ui-icon-grip-dotted-vertical', makeSidebar);
+        // if (makeSidebar) {
+        //     wrap.css({ top: viewRect.top, height: '', right: 0 });
+        // } else {
+        //     wrap.css({ height: vpPosition.height });
+        // }
+        // setNotebookWidth(cfg);
+        
         var viewRect = (liveNotebook ? document.getElementById('site') : document.body).getBoundingClientRect();
-        var wrap = $(vpCommon.getVPContainer())
-            .toggleClass('sidebar-wrapper', makeSidebar)
-            .toggleClass('float-wrapper', !makeSidebar)
-            .resizable('option', 'handles', makeSidebar ? 'w' : 'all');
-        wrap.children('.ui-resizable-w').toggleClass('ui-icon ui-icon-grip-dotted-vertical', makeSidebar);
-        if (makeSidebar) {
-            wrap.css({ top: viewRect.top, height: '', right: 0 });
-        } else {
-            wrap.css({ height: vpPosition.height });
-        }
+        var wrap = $(vpCommon.getVPContainer()).addClass('sidebar-wrapper').resizable('option', 'handles', 'w');
+        wrap.children('.ui-resizable-w').addClass('ui-icon ui-icon-grip-dotted-vertical');
+        wrap.css({ top: viewRect.top, height: '', right: 0 });
         setNotebookWidth(cfg);
     };
 
@@ -358,29 +363,28 @@
         
 
         // enable dragging and save position on stop moving
-        // TODO: 드래그 영역 처리 고려
-        vpWrapper.draggable({
-            drag: function (event, ui) {
-                var notebookWidth = $('#notebook').width();
-                var vpWrapperWidth = $(vpCommon.getVPContainer()).width();
-                // console.log('position : ', (ui.position.left + vp_wrap per_width + 22), ' width : ', notebookWidth, ' vp-wrapper-width : ', vpWrapperWidth);
-                var makeSidebar = (ui.position.left + vpWrapperWidth + 42) >= notebookWidth; // 20 is snapTolerance
-                if (makeSidebar) {
-                    ui.position.top = (liveNotebook ? document.getElementById('site') : document.body).getBoundingClientRect().top;
-                    ui.position.right = 0;
-                }
-                if (makeSidebar !== cfg.sideBar) {
-                    cfg.vp_section_display = setVpMetaData('vp_section_display', true);
-                    cfg.sideBar = setVpMetaData('sideBar', makeSidebar);
-                    toggleMinimized(cfg);
-                    toggleSidebar(cfg);
-                }
-            }, //end of drag function
-            stop: saveVpPosition,
-            containment: 'parent',
-            snap: 'body, #site',
-            snapTolerance: 20
-        });
+        // vpWrapper.draggable({
+        //     drag: function (event, ui) {
+        //         var notebookWidth = $('#notebook').width();
+        //         var vpWrapperWidth = $(vpCommon.getVPContainer()).width();
+        //         // console.log('position : ', (ui.position.left + vp_wrap per_width + 22), ' width : ', notebookWidth, ' vp-wrapper-width : ', vpWrapperWidth);
+        //         var makeSidebar = (ui.position.left + vpWrapperWidth + 42) >= notebookWidth; // 20 is snapTolerance
+        //         if (makeSidebar) {
+        //             ui.position.top = (liveNotebook ? document.getElementById('site') : document.body).getBoundingClientRect().top;
+        //             ui.position.right = 0;
+        //         }
+        //         if (makeSidebar !== cfg.sideBar) {
+        //             cfg.vp_section_display = setVpMetaData('vp_section_display', true);
+        //             cfg.sideBar = setVpMetaData('sideBar', makeSidebar);
+        //             toggleMinimized(cfg);
+        //             toggleSidebar(cfg);
+        //         }
+        //     }, //end of drag function
+        //     stop: saveVpPosition,
+        //     containment: 'parent',
+        //     snap: 'body, #site',
+        //     snapTolerance: 20
+        // });
 
         vpWrapper.resizable({
             handles: 'all',
@@ -428,14 +432,14 @@
             toggleMinimized(cfg);
         }
 
-        // 영역 dragable 제어 헤더부분에서만 기동
-        vpWrapper.draggable( "disable" );
-        $(document).on("mouseover", vpCommon.wrapSelector("#vp_header .vp-header"), function() {
-            vpWrapper.draggable( "enable" );
-        });
-        $(document).on("mouseout", vpCommon.wrapSelector("#vp_header .vp-header"), function() {
-            vpWrapper.draggable( "disable" );
-        });
+        // // 영역 dragable 제어 헤더부분에서만 기동
+        // vpWrapper.draggable( "disable" );
+        // $(document).on("mouseover", vpCommon.wrapSelector("#vp_headerContainer .vp-header"), function() {
+        //     vpWrapper.draggable( "enable" );
+        // });
+        // $(document).on("mouseout", vpCommon.wrapSelector("#vp_headerContainer .vp-header"), function() {
+        //     vpWrapper.draggable( "disable" );
+        // });
     };
 
     /**
@@ -447,7 +451,8 @@
         if (!liveNotebook)
             cfg = $.extend(true, {}, defaultConfig, cfg);
         
-        vpCommon.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + vpConst.VP_CONTAINER_CSS_URL);
+        // FIXME: css 재조정
+        vpCommon.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH +  "container" + vpConst.PATH_SEPARATOR + "vpContainer.css");
         
         var vpWrapper = $(vpCommon.getVPContainer());
         if (vpWrapper.length === 0) { // vp window doesn't exist at all
@@ -455,7 +460,7 @@
         }
 
         // update sidebar/window title
-        $(vpCommon.wrapSelector("#vp_header", ">", ".header")).text(cfg.title_sidebar + ' ');
+        $(vpCommon.wrapSelector("#vp_headerContainer", ">", ".header")).text(cfg.title_sidebar + ' ');
     };
 
     /**
